# Change Log
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/) and this project adheres to [Semantic Versioning](http://semver.org/).

## [Unreleased]

## [0.1.1] - 2023-03-16

### Added
- Better documentation for the README file, with video tutorials for the harder parts of the setup.

### Fixed
- Typos in the documentation

## [0.1.0] - 2023-03-15
Initial release! 🥳

